#line 1 "src/scan-gram.c"

#line 3 "src/scan-gram.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

/* %not-for-header */
/* %if-c-only */
/* %if-not-reentrant */
#define yy_create_buffer gram__create_buffer
#define yy_delete_buffer gram__delete_buffer
#define yy_scan_buffer gram__scan_buffer
#define yy_scan_string gram__scan_string
#define yy_scan_bytes gram__scan_bytes
#define yy_init_buffer gram__init_buffer
#define yy_flush_buffer gram__flush_buffer
#define yy_load_buffer_state gram__load_buffer_state
#define yy_switch_to_buffer gram__switch_to_buffer
#define yypush_buffer_state gram_push_buffer_state
#define yypop_buffer_state gram_pop_buffer_state
#define yyensure_buffer_stack gram_ensure_buffer_stack
#define yy_flex_debug gram__flex_debug
#define yyin gram_in
#define yyleng gram_leng
#define yylex gram_lex
#define yylineno gram_lineno
#define yyout gram_out
#define yyrestart gram_restart
#define yytext gram_text
#define yywrap gram_wrap
#define yyalloc gram_alloc
#define yyrealloc gram_realloc
#define yyfree gram_free

/* %endif */
/* %endif */
/* %ok-for-header */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* %if-c++-only */
/* %endif */

/* %if-c-only */
#ifdef yy_create_buffer
#define gram__create_buffer_ALREADY_DEFINED
#else
#define yy_create_buffer gram__create_buffer
#endif

#ifdef yy_delete_buffer
#define gram__delete_buffer_ALREADY_DEFINED
#else
#define yy_delete_buffer gram__delete_buffer
#endif

#ifdef yy_scan_buffer
#define gram__scan_buffer_ALREADY_DEFINED
#else
#define yy_scan_buffer gram__scan_buffer
#endif

#ifdef yy_scan_string
#define gram__scan_string_ALREADY_DEFINED
#else
#define yy_scan_string gram__scan_string
#endif

#ifdef yy_scan_bytes
#define gram__scan_bytes_ALREADY_DEFINED
#else
#define yy_scan_bytes gram__scan_bytes
#endif

#ifdef yy_init_buffer
#define gram__init_buffer_ALREADY_DEFINED
#else
#define yy_init_buffer gram__init_buffer
#endif

#ifdef yy_flush_buffer
#define gram__flush_buffer_ALREADY_DEFINED
#else
#define yy_flush_buffer gram__flush_buffer
#endif

#ifdef yy_load_buffer_state
#define gram__load_buffer_state_ALREADY_DEFINED
#else
#define yy_load_buffer_state gram__load_buffer_state
#endif

#ifdef yy_switch_to_buffer
#define gram__switch_to_buffer_ALREADY_DEFINED
#else
#define yy_switch_to_buffer gram__switch_to_buffer
#endif

#ifdef yypush_buffer_state
#define gram_push_buffer_state_ALREADY_DEFINED
#else
#define yypush_buffer_state gram_push_buffer_state
#endif

#ifdef yypop_buffer_state
#define gram_pop_buffer_state_ALREADY_DEFINED
#else
#define yypop_buffer_state gram_pop_buffer_state
#endif

#ifdef yyensure_buffer_stack
#define gram_ensure_buffer_stack_ALREADY_DEFINED
#else
#define yyensure_buffer_stack gram_ensure_buffer_stack
#endif

#ifdef yylex
#define gram_lex_ALREADY_DEFINED
#else
#define yylex gram_lex
#endif

#ifdef yyrestart
#define gram_restart_ALREADY_DEFINED
#else
#define yyrestart gram_restart
#endif

#ifdef yylex_init
#define gram_lex_init_ALREADY_DEFINED
#else
#define yylex_init gram_lex_init
#endif

#ifdef yylex_init_extra
#define gram_lex_init_extra_ALREADY_DEFINED
#else
#define yylex_init_extra gram_lex_init_extra
#endif

#ifdef yylex_destroy
#define gram_lex_destroy_ALREADY_DEFINED
#else
#define yylex_destroy gram_lex_destroy
#endif

#ifdef yyget_debug
#define gram_get_debug_ALREADY_DEFINED
#else
#define yyget_debug gram_get_debug
#endif

#ifdef yyset_debug
#define gram_set_debug_ALREADY_DEFINED
#else
#define yyset_debug gram_set_debug
#endif

#ifdef yyget_extra
#define gram_get_extra_ALREADY_DEFINED
#else
#define yyget_extra gram_get_extra
#endif

#ifdef yyset_extra
#define gram_set_extra_ALREADY_DEFINED
#else
#define yyset_extra gram_set_extra
#endif

#ifdef yyget_in
#define gram_get_in_ALREADY_DEFINED
#else
#define yyget_in gram_get_in
#endif

#ifdef yyset_in
#define gram_set_in_ALREADY_DEFINED
#else
#define yyset_in gram_set_in
#endif

#ifdef yyget_out
#define gram_get_out_ALREADY_DEFINED
#else
#define yyget_out gram_get_out
#endif

#ifdef yyset_out
#define gram_set_out_ALREADY_DEFINED
#else
#define yyset_out gram_set_out
#endif

#ifdef yyget_leng
#define gram_get_leng_ALREADY_DEFINED
#else
#define yyget_leng gram_get_leng
#endif

#ifdef yyget_text
#define gram_get_text_ALREADY_DEFINED
#else
#define yyget_text gram_get_text
#endif

#ifdef yyget_lineno
#define gram_get_lineno_ALREADY_DEFINED
#else
#define yyget_lineno gram_get_lineno
#endif

#ifdef yyset_lineno
#define gram_set_lineno_ALREADY_DEFINED
#else
#define yyset_lineno gram_set_lineno
#endif

#ifdef yywrap
#define gram_wrap_ALREADY_DEFINED
#else
#define yywrap gram_wrap
#endif

/* %endif */

#ifdef yyalloc
#define gram_alloc_ALREADY_DEFINED
#else
#define yyalloc gram_alloc
#endif

#ifdef yyrealloc
#define gram_realloc_ALREADY_DEFINED
#else
#define yyrealloc gram_realloc
#endif

#ifdef yyfree
#define gram_free_ALREADY_DEFINED
#else
#define yyfree gram_free
#endif

/* %if-c-only */

#ifdef yytext
#define gram_text_ALREADY_DEFINED
#else
#define yytext gram_text
#endif

#ifdef yyleng
#define gram_leng_ALREADY_DEFINED
#else
#define yyleng gram_leng
#endif

#ifdef yyin
#define gram_in_ALREADY_DEFINED
#else
#define yyin gram_in
#endif

#ifdef yyout
#define gram_out_ALREADY_DEFINED
#else
#define yyout gram_out
#endif

#ifdef yy_flex_debug
#define gram__flex_debug_ALREADY_DEFINED
#else
#define yy_flex_debug gram__flex_debug
#endif

#ifdef yylineno
#define gram_lineno_ALREADY_DEFINED
#else
#define yylineno gram_lineno
#endif

/* %endif */

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
/* %if-c-only */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>
/* %endif */

/* %if-tables-serialization */
/* %endif */
/* end standard C headers. */

/* %if-c-or-c++ */
/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* %endif */

/* begin standard C++ headers. */
/* %if-c++-only */
/* %endif */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* %not-for-header */
/* Returned upon end-of-file. */
#define YY_NULL 0
/* %ok-for-header */

/* %not-for-header */
/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))
/* %ok-for-header */

/* %if-reentrant */
/* %endif */

/* %if-not-reentrant */

/* %endif */

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

/* %if-not-reentrant */
extern int yyleng;
/* %endif */

/* %if-c-only */
/* %if-not-reentrant */
extern FILE *yyin, *yyout;
/* %endif */
/* %endif */

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
/* %if-c-only */
	FILE *yy_input_file;
/* %endif */

/* %if-c++-only */
/* %endif */

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
/* %if-not-reentrant */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */
/* %endif */
/* %ok-for-header */

/* %endif */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* %if-c-only Standard (non-C++) definition */

/* %if-not-reentrant */
/* %not-for-header */
/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;
/* %ok-for-header */

/* %endif */

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

/* %endif */

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* %% [1.0] yytext/yyin/yyout/yy_state_type/yylineno etc. def's & init go here */
/* Begin user sect3 */

#define gram_wrap() (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

#define FLEX_DEBUG
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

/* %% [1.5] DFA */

/* %if-c-only Standard (non-C++) definition */

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* %endif */

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
/* %% [2.0] code to fiddle yytext and yyleng for yymore() goes here \ */\
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
/* %% [3.0] code to copy yytext_ptr to yytext[] goes here, if %array \ */\
	(yy_c_buf_p) = yy_cp;
/* %% [4.0] data tables for the DFA and the user's section 1 definitions go here */
#define YY_NUM_RULES 132
#define YY_END_OF_BUFFER 133
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_accept[612] =
    {   0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,   93,   93,  116,  116,  116,  116,
        0,    0,    0,    0,  133,   80,    2,    2,    2,   70,
       80,   69,   80,    1,   65,   80,   66,   66,   61,   64,
       77,   62,   65,   79,   65,   73,   63,   80,   90,   90,
       90,  131,  131,   99,  131,   98,  115,  131,  131,  131,
      131,  131,  131,  131,   81,   95,   94,   97,  131,   84,
        2,    2,    1,   84,   83,   82,   84,  101,  101,  102,
      100,   81,  122,  131,  121,  131,  131,  131,  125,  128,

      129,  131,   92,  131,  131,  120,  131,  119,  131,  118,
      131,  117,   87,    2,    2,    1,   85,   87,   87,   86,
       87,   88,    2,    2,    1,   88,   88,   80,    2,   78,
       60,    0,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   72,   65,   65,    4,    3,   68,   66,   68,    0,
       76,    0,    0,   90,   89,   99,  114,  114,  112,  103,
      114,  105,  106,  107,  108,  109,  110,  114,  111,  114,
      131,    0,    0,    0,    0,    0,    0,   96,  101,  101,
      102,  130,  123,  124,    0,  126,    0,  125,  127,    0,

       91,    0,   92,    0,   93,    0,  120,  116,  116,  116,
      116,  116,  118,   87,   85,   60,    0,    0,   74,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,    3,   68,   67,   75,   71,    0,  103,    0,    0,
      104,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,    0,    0,    0,    0,    0,    0,    0,
        0,    0,    0,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,

       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,    0,  103,    0,    0,   60,    7,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   22,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   34,   60,   60,
       60,   60,   60,   60,   41,   60,   44,   60,   60,   47,
        0,    0,    0,   60,    8,   60,   60,   60,   13,   14,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       25,   60,   60,   60,   60,   60,   60,   60,   30,   60,

       32,   60,   60,   60,   60,   60,   38,   60,   40,   42,
       45,   60,    0,    0,  113,    6,   60,   10,   60,   60,
       60,   15,   60,   60,   60,   19,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   31,   60,   60,
       60,   60,   60,   60,   60,   60,   60,    0,   60,   11,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,    0,
       58,   60,   60,   36,   60,   37,   60,   60,   60,   46,
        5,    0,    0,   60,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   60,   21,   60,   60,   60,   60,   27,

       60,   57,   28,   60,   60,   60,   60,   39,   60,   60,
        0,   60,   60,   60,   60,   60,   16,   53,   60,   60,
       60,   60,   23,   24,   60,   60,   60,   60,   60,   60,
       60,   60,   60,    0,    0,   60,   60,   12,   60,   60,
       60,   60,   18,   60,   60,   60,   60,   60,   60,   35,
       60,   60,   60,    0,   60,   60,   60,   60,   17,   60,
       60,   50,   60,   60,   60,   33,   48,   43,   59,    9,
       51,   60,   60,    0,   54,   60,   60,   50,   50,   60,
       60,   60,   49,   52,   60,   60,   50,   60,   60,   60,
       60,   20,   60,   60,   60,   60,   26,   56,   60,   60,

       60,   60,   60,   55,   60,   60,   60,   60,   60,   29,
        0
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    5,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    6,    7,    8,    9,    7,   10,    7,   11,   12,
       13,   14,    7,   15,   16,   17,   18,   19,   20,   20,
       20,   20,   20,   20,   20,   21,   21,   22,   23,   24,
       25,   26,   27,    7,   28,   28,   28,   28,   28,   28,
       29,   29,   29,   29,   29,   29,   29,   29,   29,   29,
       29,   29,   29,   29,   30,   29,   29,   31,   29,   29,
       32,   33,   34,    7,   35,    7,   36,   37,   38,   39,

       40,   41,   42,   43,   44,   29,   45,   46,   47,   48,
       49,   50,   51,   52,   53,   54,   55,   56,   29,   57,
       58,   29,   59,   60,   61,    7,    1,   62,   62,   62,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   63,   63,   63,   63,   63,   63,   63,
       63,   63,   63,   63,   63,   63,   63,   63,   63,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,   64,   64,   64,   64,   64,   64,   64,   64,   64,
       64,    1,    1,   65,   65,   65,   65,   65,   65,   65,

       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   66,   67,   67,   67,   67,   67,   67,
       67,   67,   67,   67,   67,   67,   68,   67,   67,   69,
       70,   70,   70,   71,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[73] =
    {   0,
        1,    2,    3,    2,    2,    2,    1,    4,    1,    4,
        4,    1,    1,    4,    4,    5,    6,    2,    7,    7,
        7,    1,    4,    8,    4,    8,    1,    7,    7,    7,
        7,    9,    1,   10,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    7,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    4,    4,
        4,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1
    } ;

static const flex_int16_t yy_base[629] =
    {   0,
        0, 1327,   68,   69,   83,  155,   87,   88,   97,   98,
      108,  159,  101,  108,  179,  195,  265,  335,  227,  228,
      405,  475,  238,  239,  251,  275,  282,  298,  302,  309,
      547, 1326,  346,  373, 1334,    0, 1337, 1337, 1330, 1337,
      610, 1337, 1337, 1337,  669,   61,  100,   57,    0, 1337,
       71, 1337,    0, 1337, 1320, 1337, 1337, 1285, 1337, 1327,
     1311, 1337, 1337, 1337, 1325, 1337,  737,   73, 1263,   79,
       18,   65,  107, 1264, 1337, 1337, 1337, 1337, 1312, 1337,
     1337, 1321, 1337,  104, 1337, 1337, 1277, 1306,  159, 1297,
     1337, 1304, 1337, 1258, 1337,  178,  146,  183, 1337, 1337,

     1337,   71, 1337, 1315,  381, 1337, 1314, 1337,  395, 1337,
     1313, 1337,    0, 1337, 1312,    0,    0,  181, 1337, 1337,
     1268, 1337, 1337, 1310, 1337,  190, 1266,    0, 1337, 1337,
        0,  400, 1267, 1261,  136,  212, 1265, 1262, 1267, 1258,
      255, 1265,  243, 1249,  211,  170,  203,  276, 1255, 1262,
     1265, 1337,    0,    0, 1337,    0,    0,  298,  405, 1274,
     1337, 1291, 1254, 1337, 1337, 1337, 1337, 1294, 1337,  119,
      411, 1337, 1337, 1337, 1337, 1337, 1337,  434, 1337,  475,
     1337,  265,  293,  303,  309,  355,  358, 1337, 1280,  239,
     1271, 1337, 1337, 1337,  485, 1337,  515, 1337, 1337,  520,

     1337,  525, 1337,  535, 1261, 1290, 1337, 1337,  540, 1259,
     1288,  619, 1337,    0,    0,    0,  628, 1287, 1337, 1241,
     1249,  426, 1235, 1236, 1233, 1234,   87, 1231, 1246, 1237,
     1232,  126, 1241, 1226, 1230,  379, 1236, 1221, 1222,  237,
     1221, 1221, 1229, 1230, 1233, 1216, 1222, 1216, 1221, 1212,
     1225,    0,    0,    0, 1337, 1337, 1214,  182,  760,  783,
      789,  372,  394,  438,  669,  451, 1258,  747,  306, 1257,
      756,  744, 1256,  810,  176, 1255,  829,  834, 1254,  839,
      844,  255, 1253, 1219, 1214, 1198,   71, 1198, 1211, 1196,
     1200, 1208, 1207, 1206, 1229, 1205, 1189, 1200, 1187, 1224,

     1203, 1196, 1197,  323,  422,  198, 1184, 1185,  305, 1196,
     1185, 1192, 1176, 1187, 1183, 1176, 1180, 1186, 1185, 1175,
     1186, 1184, 1181, 1337,  832,  838, 1168,    0, 1177, 1163,
     1169, 1164, 1177, 1156, 1161, 1174, 1195, 1171, 1159, 1168,
     1163, 1151,    0, 1155, 1150, 1163,  286, 1162, 1157, 1160,
     1155, 1145, 1157, 1149, 1140, 1147, 1153, 1152, 1137,  328,
     1146, 1135, 1148, 1133,    0, 1138,    0, 1137, 1135,    0,
     1177,  861,  867, 1124,    0, 1135, 1140, 1124,    0,    0,
      374, 1124, 1127,  376, 1140, 1123, 1138, 1137, 1136, 1127,
        0, 1120, 1128, 1120, 1126, 1118, 1112, 1110,    0, 1109,

        0, 1146, 1122, 1120, 1109, 1106,    0, 1103,    0,  377,
        0, 1103,  485,  890, 1337,    0, 1101, 1101, 1115, 1096,
     1095,  712, 1098, 1100, 1096,    0, 1101, 1104, 1093, 1095,
     1091, 1106, 1101, 1104, 1099, 1089, 1097,  859, 1086, 1095,
     1082, 1097, 1092, 1082, 1076, 1075, 1088,  623,  728,    0,
     1073, 1086, 1085, 1072, 1071, 1082, 1066, 1067, 1103, 1078,
     1081, 1068, 1075, 1059, 1060, 1057, 1058, 1072, 1057,  888,
     1337, 1072, 1059,    0, 1054,    0, 1057, 1068, 1067,    0,
     1337, 1099, 1093, 1050, 1049, 1049, 1038, 1025, 1014, 1013,
     1021, 1007, 1009,  989,    0,  977,  970,  979,  973,    0,

      972,    0,    0,  912,  906,  919,  903,    0,  917,  916,
      917,  872,  865,  864,  878,  877,    0,    0,  868,  846,
      833,  845,    0,    0,  823,  802,  801,  810,  782,  767,
      766,  759,  740,  775,  779,  735,  732,    0,  720,  717,
      698,  688,    0,  676,  672,  730,  755,  653,  648,    0,
      642,  653,  652,  473,  646,  645,  627,  626,  917,  623,
      592,  930,  585,  485,  489,    0,    0,    0,    0,    0,
        0,  492,  470,  935, 1337,  760,  460,  941,  946,  455,
      446,  444,    0,    0,  451,  434,  959,  420,  400,  383,
      345,    0,  342,  322,  292,  287,    0,    0,  292,  282,

      280,  241,  232,    0,  238,  188,  176,  175,  126,    0,
     1337,  966,  976,  986,  996, 1006, 1016, 1021, 1024, 1031,
     1041, 1051, 1059, 1064, 1067, 1074, 1080, 1087
    } ;

static const flex_int16_t yy_def[629] =
    {   0,
      611,    1,  612,  612,  613,  613,    6,    6,    6,    6,
      614,  614,  615,  615,    6,    6,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,    6,    6,    6,
      611,   31,  616,  616,  611,  617,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  618,  618,  617,  611,
      611,  611,  619,  611,  619,  611,  611,  617,  611,  611,
      611,  611,  611,  611,  611,  611,  620,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  621,  621,  611,
      611,  621,  611,  611,  611,  611,  611,  611,  611,  611,

      611,  611,  611,  611,  611,  611,  611,  611,  622,  611,
      611,  611,  623,  611,  611,  623,  624,  611,  611,  611,
      623,  611,  611,  611,  611,  611,  611,  617,  611,  611,
      625,  611,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  611,   45,  619,  611,  626,  627,  618,  627,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  621,  621,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,

      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  623,  624,  625,  611,  611,  611,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  626,  627,  159,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  622,  611,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,

      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  611,  611,  611,  611,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      611,  611,  611,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,

      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  611,  611,  611,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  611,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  611,
      611,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      611,  611,  611,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,

      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      628,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  628,  628,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  628,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
      625,  625,  625,  611,  611,  625,  625,  611,  611,  625,
      625,  625,  625,  625,  625,  625,  611,  625,  625,  625,
      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,

      625,  625,  625,  625,  625,  625,  625,  625,  625,  625,
        0,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611
    } ;

static const flex_int16_t yy_nxt[1410] =
    {   0,
       36,   37,   38,   37,   39,   37,   36,   40,   36,   41,
       42,   36,   36,   43,   44,   36,   45,   46,   47,   48,
       48,   49,   50,   51,   52,   43,   36,   53,   53,   53,
       53,   54,   36,   36,   55,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   53,   53,
       53,   53,   53,   53,   53,   53,   53,   53,   56,   57,
       43,   36,   36,   36,   36,   36,   36,   36,   36,   36,
       36,   36,   60,   60,  155,  158,  158,  158,  156,  184,
      184,   61,   61,   62,  160,   64,   62,   65,  201,   76,
       76,   63,   63,   66,   77,   77,  161,   63,   63,   78,

       78,   63,   63,  202,   79,   79,  330,   63,   63,   81,
       38,   81,   82,   81,  331,   67,   89,  155,  158,  158,
      158,  156,   83,   89,   90,   84,   91,  185,  185,   85,
      159,   90,  293,   91,  181,  181,  181,  258,  258,   86,
      183,  183,  183,  294,   62,   62,   62,   68,   69,   70,
       71,   72,   73,   74,   75,   62,  159,   64,   62,   65,
       81,   38,   81,   82,   81,   66,  299,   87,  186,  186,
      186,  196,   92,   83,  190,  222,   84,  610,  197,   92,
       85,   62,  300,   63,  189,  223,   93,   67,   94,   95,
       86,  193,  198,  201,  155,  194,   96,   62,  156,   63,

      324,  324,   93,  155,   94,   95,  199,  156,  202,  242,
      195,   63,   96,  243,  609,  200,   62,   62,   62,   68,
       69,   70,   71,   72,   73,   74,   75,   63,  608,   62,
       62,   63,   63,  352,   93,   93,  353,   95,   95,  607,
       62,   62,   63,   63,   96,   96,  239,  244,   63,   63,
       62,  102,  102,  103,  190,  104,  245,  611,  224,   63,
       63,   63,  240,  225,  189,  241,   62,   62,  226,   63,
       63,   63,   93,  606,   97,   95,  310,  103,  235,  104,
      311,  605,   96,  105,  106,   63,  107,  212,   98,  108,
      231,  236,   63,  604,  232,  603,  237,   63,   62,   62,

      106,  392,  107,  233,  110,  108,  111,  105,   63,   62,
       62,  110,  112,  111,  109,  246,  158,  158,  158,  112,
      392,  602,   62,   99,  247,  100,  181,  181,  181,  601,
      109,  196,  600,  248,  109,  599,   62,   62,  197,   63,
      356,  109,   93,  405,   97,   95,   62,  123,   38,  123,
      124,  123,   96,   62,  181,  181,  181,  357,   98,  598,
      125,  348,  405,  126,  181,  181,  181,   63,  349,   62,
      262,  262,  262,   62,  123,   38,  123,  124,  123,  597,
       62,  127,  204,  205,  204,  206,  204,  125,  596,  420,
      126,  424,  445,   99,  304,  100,  209,  210,  209,  211,

      209,  217,  217,  217,  218,  217,   62,   62,  421,   63,
      424,  446,   93,  305,   97,   95,  263,  263,  263,  264,
      264,  264,   96,  254,  254,  254,  306,  212,   98,  259,
      259,  259,  254,  181,  181,  181,  595,   63,  259,  594,
      254,  254,  254,  254,  254,  254,  259,  259,  259,  259,
      259,  259,  260,  260,  260,  181,  181,  181,  219,  593,
      350,  260,  286,   99,  193,  101,  287,  351,  194,  260,
      260,  260,  260,  260,  260,  481,   62,   62,  288,   63,
      535,  592,   93,  195,   97,   95,  265,  266,  265,  267,
      265,  591,   96,  261,  261,  261,  590,  589,   98,  181,

      181,  181,  261,  448,  448,  448,  588,   63,  586,  584,
      261,  261,  261,  261,  261,  261,  268,  269,  268,  270,
      268,  271,  272,  271,  273,  271,  274,  275,  274,  276,
      274,  583,  582,   99,  581,  101,  204,  205,  204,  206,
      204,  278,  210,  278,  279,  278,   62,  113,  114,   38,
      114,  115,  114,  113,  113,  113,  113,  113,  113,  113,
      113,  116,  113,  117,  118,  119,  119,  119,  113,  113,
      113,  113,  113,  113,  117,  117,  117,  117,  113,  113,
      120,  117,  117,  117,  117,  117,  117,  117,  117,  117,
      117,  117,  117,  117,  117,  117,  117,  117,  117,  117,

      117,  117,  117,  117,  117,  113,  113,  113,  113,  113,
      113,  113,  113,  113,  113,  113,  113,  113,  113,  130,
      281,  282,  281,  283,  281,  481,  131,  482,  483,  217,
      217,  217,  218,  217,  580,  577,  132,  131,  131,  131,
      131,  448,  448,  448,  131,  131,  133,  134,  135,  136,
      137,  138,  139,  140,  131,  141,  142,  143,  144,  145,
      131,  146,  147,  148,  149,  150,  131,  151,  152,  128,
      265,  266,  265,  267,  265,  128,  576,  128,  573,  572,
      128,  128,  571,  570,  153,  153,  219,  154,  154,  154,
      128,  569,  568,  567,  566,  128,  154,  154,  154,  154,

      565,  128,  128,  154,  154,  154,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  154,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  154,  154,  454,  562,  561,
      128,  128,  128,  128,  128,  128,  128,  128,  128,  128,
      128,  168,  560,  484,  169,  563,  455,  169,  268,  269,
      268,  270,  268,  198,  559,  170,  170,  271,  272,  271,
      273,  271,  485,  169,  564,  558,  171,  199,  557,  169,
      564,  556,  172,  173,  555,  585,  200,  174,  325,  325,
      325,  481,  535,  554,  175,  553,  535,  325,  176,  564,
      177,  178,  179,  180,  585,  325,  325,  325,  325,  325,

      325,  326,  326,  326,  552,  551,  550,  261,  261,  261,
      326,  274,  275,  274,  276,  274,  261,  549,  326,  326,
      326,  326,  326,  326,  261,  261,  261,  261,  261,  261,
      204,  205,  204,  206,  204,  278,  210,  278,  279,  278,
      278,  210,  278,  279,  278,  281,  282,  281,  283,  281,
      372,  372,  372,  548,  547,  546,  373,  373,  373,  372,
      470,  470,  470,  470,  470,  373,  545,  372,  372,  372,
      372,  372,  372,  373,  373,  373,  373,  373,  373,  414,
      414,  414,  544,  471,  543,  415,  415,  415,  414,  470,
      470,  470,  470,  470,  415,  542,  414,  414,  414,  414,

      414,  414,  415,  415,  415,  415,  415,  415,  260,  260,
      260,  541,  471,  540,  539,  538,  537,  260,  574,  574,
      574,  574,  574,  536,  535,  260,  260,  260,  260,  260,
      260,  578,  578,  578,  578,  578,  574,  574,  574,  574,
      574,  575,  578,  578,  578,  578,  578,  587,  587,  587,
      587,  587,  533,  532,  579,  531,  530,  529,  528,  575,
      587,  587,  587,  587,  587,  579,   59,   59,   59,   59,
       59,   59,   59,   59,   59,   59,   63,   63,   63,   63,
       63,   63,   63,   63,   63,   63,   80,   80,   80,   80,
       80,   80,   80,   80,   80,   80,   88,   88,   88,   88,

       88,   88,   88,   88,   88,   88,  122,  122,  122,  122,
      122,  122,  122,  122,  122,  122,  128,  527,  526,  525,
      128,  128,  524,  523,  522,  128,  157,  157,  154,  154,
      154,  167,  167,  167,  167,  167,  167,  167,  167,  167,
      167,  189,  189,  189,  189,  189,  189,  189,  521,  189,
      189,  208,  208,  208,  208,  208,  208,  208,  208,  214,
      520,  519,  214,  214,  518,  517,  214,  214,  215,  215,
      215,  216,  216,  216,  252,  252,  516,  252,  252,  252,
      252,  252,  252,  252,  253,  253,  253,  534,  534,  515,
      534,  534,  534,  534,  534,  534,  534,  514,  513,  512,

      511,  481,  510,  509,  508,  507,  506,  505,  504,  503,
      502,  501,  500,  499,  498,  497,  496,  495,  494,  493,
      492,  491,  490,  489,  488,  487,  486,  480,  479,  478,
      477,  476,  475,  474,  473,  472,  469,  468,  467,  466,
      465,  464,  463,  462,  461,  460,  459,  458,  457,  456,
      453,  452,  451,  450,  449,  447,  444,  443,  442,  441,
      440,  439,  438,  437,  436,  435,  434,  433,  432,  431,
      430,  429,  428,  427,  426,  425,  423,  422,  419,  418,
      417,  416,  413,  412,  411,  410,  409,  408,  407,  406,
      404,  403,  402,  401,  400,  399,  398,  397,  396,  395,

      394,  393,  391,  390,  389,  388,  387,  386,  385,  384,
      383,  382,  381,  380,  379,  378,  377,  376,  375,  374,
      371,  370,  369,  368,  367,  366,  365,  364,  363,  362,
      361,  360,  359,  358,  355,  354,  347,  346,  345,  344,
      343,  342,  341,  340,  339,  338,  337,  336,  335,  334,
      333,  332,  329,  328,  327,  282,  210,  275,  272,  269,
      266,  323,  322,  321,  320,  319,  318,  317,  316,  315,
      314,  313,  312,  309,  308,  307,  303,  302,  301,  298,
      297,  296,  295,  292,  291,  290,  289,  285,  284,  217,
      210,  280,  205,  277,  191,  190,  167,  257,  256,  255,

      251,  250,  249,  238,  234,  230,  229,  228,  227,  221,
      220,  163,  129,  163,  129,  213,  207,  203,  192,  190,
      191,  190,  163,  129,  188,  187,  182,  166,  165,  164,
      163,  162,  129,  611,  121,   58,   35,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,

      611,  611,  611,  611,  611,  611,  611,  611,  611
    } ;

static const flex_int16_t yy_chk[1410] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    3,    4,   46,   48,   48,   48,   46,   71,
       71,    3,    4,    5,   51,    5,    5,    5,  102,    7,
        8,    7,    8,    5,    7,    8,   51,    7,    8,    9,

       10,    9,   10,  102,    9,   10,  287,    9,   10,   11,
       11,   11,   11,   11,  287,    5,   13,   84,   47,   47,
       47,   84,   11,   14,   13,   11,   13,   72,   72,   11,
       47,   14,  227,   14,   68,   68,   68,  170,  170,   11,
       70,   70,   70,  227,    5,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    6,   47,    6,    6,    6,
       12,   12,   12,   12,   12,    6,  232,   12,   73,   73,
       73,   97,   13,   12,   89,  135,   12,  609,   97,   14,
       12,   15,  232,   15,   89,  135,   15,    6,   15,   15,
       12,   96,   98,  275,  118,   96,   15,   16,  118,   16,

      258,  258,   16,  126,   16,   16,   98,  126,  275,  146,
       96,   15,   16,  146,  608,   98,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,   16,  607,   19,
       20,   19,   20,  306,   19,   20,  306,   19,   20,  606,
       23,   24,   23,   24,   19,   20,  145,  147,   23,   24,
       15,   23,   24,   25,  190,   25,  147,  282,  136,   19,
       20,   25,  145,  136,  190,  145,   16,   17,  136,   17,
       23,   24,   17,  605,   17,   17,  240,   26,  143,   26,
      240,  603,   17,   25,   27,   26,   27,  282,   17,   27,
      141,  143,   27,  602,  141,  601,  143,   17,   19,   20,

       28,  347,   28,  141,   29,   28,   29,   26,   28,   23,
       24,   30,   29,   30,   27,  148,  158,  158,  158,   30,
      347,  600,   25,   17,  148,   17,  182,  182,  182,  599,
       28,  269,  596,  148,   29,  595,   17,   18,  269,   18,
      309,   30,   18,  360,   18,   18,   26,   33,   33,   33,
       33,   33,   18,   27,  183,  183,  183,  309,   18,  594,
       33,  304,  360,   33,  184,  184,  184,   18,  304,   28,
      185,  185,  185,   29,   34,   34,   34,   34,   34,  593,
       30,   34,  105,  105,  105,  105,  105,   34,  591,  381,
       34,  384,  410,   18,  236,   18,  109,  109,  109,  109,

      109,  132,  132,  132,  132,  132,   18,   21,  381,   21,
      384,  410,   21,  236,   21,   21,  186,  186,  186,  187,
      187,  187,   21,  159,  159,  159,  236,  109,   21,  171,
      171,  171,  159,  262,  262,  262,  590,   21,  171,  589,
      159,  159,  159,  159,  159,  159,  171,  171,  171,  171,
      171,  171,  178,  178,  178,  263,  263,  263,  132,  588,
      305,  178,  222,   21,  266,   21,  222,  305,  266,  178,
      178,  178,  178,  178,  178,  554,   21,   22,  222,   22,
      554,  586,   22,  266,   22,   22,  195,  195,  195,  195,
      195,  585,   22,  180,  180,  180,  582,  581,   22,  264,

      264,  264,  180,  413,  413,  413,  580,   22,  577,  573,
      180,  180,  180,  180,  180,  180,  197,  197,  197,  197,
      197,  200,  200,  200,  200,  200,  202,  202,  202,  202,
      202,  572,  565,   22,  564,   22,  204,  204,  204,  204,
      204,  209,  209,  209,  209,  209,   22,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,

       31,   31,   31,   31,   31,   31,   31,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   31,   41,
      212,  212,  212,  212,  212,  448,   41,  448,  448,  217,
      217,  217,  217,  217,  563,  561,   41,   41,   41,   41,
       41,  448,  448,  448,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   41,
       41,   41,   41,   41,   41,   41,   41,   41,   41,   45,
      265,  265,  265,  265,  265,   45,  560,   45,  558,  557,
       45,   45,  556,  555,   45,   45,  217,   45,   45,   45,
       45,  553,  552,  551,  549,   45,   45,   45,   45,   45,

      548,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   45,   45,   45,   45,   45,   45,  422,  545,  544,
       45,   45,   45,   45,   45,   45,   45,   45,   45,   45,
       45,   67,  542,  449,   67,  546,  422,   67,  268,  268,
      268,  268,  268,  272,  541,   67,   67,  271,  271,  271,
      271,  271,  449,   67,  546,  540,   67,  272,  539,   67,
      547,  537,   67,   67,  536,  576,  272,   67,  259,  259,
      259,  535,  534,  535,   67,  533,  535,  259,   67,  547,
       67,   67,   67,   67,  576,  259,  259,  259,  259,  259,

      259,  260,  260,  260,  532,  531,  530,  261,  261,  261,
      260,  274,  274,  274,  274,  274,  261,  529,  260,  260,
      260,  260,  260,  260,  261,  261,  261,  261,  261,  261,
      277,  277,  277,  277,  277,  278,  278,  278,  278,  278,
      280,  280,  280,  280,  280,  281,  281,  281,  281,  281,
      325,  325,  325,  528,  527,  526,  326,  326,  326,  325,
      438,  438,  438,  438,  438,  326,  525,  325,  325,  325,
      325,  325,  325,  326,  326,  326,  326,  326,  326,  372,
      372,  372,  522,  438,  521,  373,  373,  373,  372,  470,
      470,  470,  470,  470,  373,  520,  372,  372,  372,  372,

      372,  372,  373,  373,  373,  373,  373,  373,  414,  414,
      414,  519,  470,  516,  515,  514,  513,  414,  559,  559,
      559,  559,  559,  512,  511,  414,  414,  414,  414,  414,
      414,  562,  562,  562,  562,  562,  574,  574,  574,  574,
      574,  559,  578,  578,  578,  578,  578,  579,  579,  579,
      579,  579,  510,  509,  562,  507,  506,  505,  504,  574,
      587,  587,  587,  587,  587,  578,  612,  612,  612,  612,
      612,  612,  612,  612,  612,  612,  613,  613,  613,  613,
      613,  613,  613,  613,  613,  613,  614,  614,  614,  614,
      614,  614,  614,  614,  614,  614,  615,  615,  615,  615,

      615,  615,  615,  615,  615,  615,  616,  616,  616,  616,
      616,  616,  616,  616,  616,  616,  617,  501,  499,  498,
      617,  617,  497,  496,  494,  617,  618,  618,  619,  619,
      619,  620,  620,  620,  620,  620,  620,  620,  620,  620,
      620,  621,  621,  621,  621,  621,  621,  621,  493,  621,
      621,  622,  622,  622,  622,  622,  622,  622,  622,  623,
      492,  491,  623,  623,  490,  489,  623,  623,  624,  624,
      624,  625,  625,  625,  626,  626,  488,  626,  626,  626,
      626,  626,  626,  626,  627,  627,  627,  628,  628,  487,
      628,  628,  628,  628,  628,  628,  628,  486,  485,  484,

      483,  482,  479,  478,  477,  475,  473,  472,  469,  468,
      467,  466,  465,  464,  463,  462,  461,  460,  459,  458,
      457,  456,  455,  454,  453,  452,  451,  447,  446,  445,
      444,  443,  442,  441,  440,  439,  437,  436,  435,  434,
      433,  432,  431,  430,  429,  428,  427,  425,  424,  423,
      421,  420,  419,  418,  417,  412,  408,  406,  405,  404,
      403,  402,  400,  398,  397,  396,  395,  394,  393,  392,
      390,  389,  388,  387,  386,  385,  383,  382,  378,  377,
      376,  374,  371,  369,  368,  366,  364,  363,  362,  361,
      359,  358,  357,  356,  355,  354,  353,  352,  351,  350,

      349,  348,  346,  345,  344,  342,  341,  340,  339,  338,
      337,  336,  335,  334,  333,  332,  331,  330,  329,  327,
      323,  322,  321,  320,  319,  318,  317,  316,  315,  314,
      313,  312,  311,  310,  308,  307,  303,  302,  301,  300,
      299,  298,  297,  296,  295,  294,  293,  292,  291,  290,
      289,  288,  286,  285,  284,  283,  279,  276,  273,  270,
      267,  257,  251,  250,  249,  248,  247,  246,  245,  244,
      243,  242,  241,  239,  238,  237,  235,  234,  233,  231,
      230,  229,  228,  226,  225,  224,  223,  221,  220,  218,
      211,  210,  206,  205,  191,  189,  168,  163,  162,  160,

      151,  150,  149,  144,  142,  140,  139,  138,  137,  134,
      133,  127,  124,  121,  115,  111,  107,  104,   94,   92,
       90,   88,   87,   82,   79,   74,   69,   65,   61,   60,
       58,   55,   39,   35,   32,    2,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,
      611,  611,  611,  611,  611,  611,  611,  611,  611,  611,

      611,  611,  611,  611,  611,  611,  611,  611,  611
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int yy_flex_debug;
int yy_flex_debug = 1;

static const flex_int16_t yy_rule_linenum[132] =
    {   0,
      214,  217,  218,  219,  225,  243,  244,  245,  246,  247,
      248,  249,  250,  251,  252,  253,  254,  255,  256,  257,
      258,  259,  260,  261,  262,  263,  264,  265,  266,  267,
      268,  269,  270,  271,  272,  273,  274,  275,  276,  277,
      278,  279,  280,  281,  282,  283,  284,  288,  292,  296,
      299,  300,  301,  302,  303,  304,  305,  306,  307,  309,
      314,  315,  316,  317,  319,  326,  327,  331,  337,  340,
      341,  344,  347,  355,  362,  363,  364,  370,  377,  384,
      405,  420,  435,  441,  460,  474,  493,  509,  526,  527,
      538,  549,  550,  562,  572,  577,  587,  599,  623,  635,

      649,  650,  661,  665,  669,  670,  671,  672,  673,  674,
      675,  678,  680,  684,  696,  712,  717,  718,  724,  725,
      736,  742,  748,  754,  770,  771,  775,  782,  798,  818,
      857
    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "/Users/akim/src/gnu/bison/src/scan-gram.l"
/* Bison Grammar Scanner                             -*- C -*-

   Copyright (C) 2002-2015, 2018-2021 Free Software Foundation, Inc.

   This file is part of Bison, the GNU Compiler Compiler.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */
#define YY_NO_INPUT 1
#line 24 "/Users/akim/src/gnu/bison/src/scan-gram.l"
#include <c-ctype.h>
#include <errno.h>
#include <mbswidth.h>
#include <quote.h>
#include <quotearg.h>

#include "src/complain.h"
#include "src/files.h"
#include "src/getargs.h"
#include "src/gram.h"
#include "src/reader.h"
#include "src/scan-gram.h"
#include "src/uniqstr.h"

#define FLEX_PREFIX(Id) gram_ ## Id
#include "src/flex-scanner.h"

/* Work around a bug in flex 2.5.31.  See Debian bug 333231
   <https://bugs.debian.org/333231>.  */
#undef gram_wrap
#define gram_wrap() 1

#define YY_DECL GRAM_LEX_DECL

/* Location of scanner cursor.  */
static boundary scanner_cursor;

#define YY_USER_ACTION  location_compute (loc, &scanner_cursor, yytext, yyleng);

/* Report that yytext is an extension, and evaluate to its token kind.  */
#define BISON_DIRECTIVE(Directive)                              \
  (bison_directive (loc, yytext), PERCENT_ ## Directive)

#define RETURN_PERCENT_PARAM(Value)             \
  RETURN_VALUE(PERCENT_PARAM, param_ ## Value)

#define RETURN_PERCENT_FLAG(Value)                      \
  RETURN_VALUE(PERCENT_FLAG, uniqstr_new (Value))

#define RETURN_VALUE(Token, Value)              \
  do {                                          \
    val->Token = Value;                         \
    return Token;                               \
  } while (0)

#define ROLLBACK_CURRENT_TOKEN                                  \
  do {                                                          \
    scanner_cursor.column -= mbsnwidth (yytext, yyleng, 0);     \
    scanner_cursor.byte -= yyleng;                              \
    yyless (0);                                                 \
  } while (0)

#define DEPRECATED_DIRECTIVE(Msg)                               \
  do {                                                          \
    deprecated_directive (loc, yytext, Msg);                    \
    scanner_cursor.column -= mbsnwidth (Msg, strlen (Msg), 0);  \
    scanner_cursor.byte -= strlen (Msg);                        \
    for (size_t i = strlen (Msg); i != 0; --i)                  \
      unput (Msg[i - 1]);                                       \
  } while (0)


#define STRING_GROW_ESCAPE(Char)                                \
  do {                                                          \
    verify (UCHAR_MAX < ULONG_MAX);                             \
    long c = Char;                                              \
    bool valid = 0 < c && c <= UCHAR_MAX;                       \
    if (!valid)                                                 \
      complain (loc, complaint,                                 \
                _("invalid number after \\-escape: %s"),        \
                yytext + 1);                                    \
    if (YY_START == SC_ESCAPED_CHARACTER)                       \
      STRING_1GROW (valid ? c : '?');                           \
    else                                                        \
      STRING_GROW ();                                           \
  } while (0)


/* The current file name.  Might change with #line.  */
static uniqstr current_file = NULL;

/* A string representing the most recently saved token.  */
static char *last_string = NULL;

/* Bracketed identifier. */
static uniqstr bracketed_id_str = NULL;
static location bracketed_id_loc;
static boundary bracketed_id_start;
static int bracketed_id_context_state = 0;

void
gram_scanner_last_string_free (void)
{
  STRING_FREE ();
}

static void handle_syncline (char *, location);
static int scan_integer (char const *p, int base, location loc);
static int convert_ucn_to_byte (char const *hex_text);
static void unexpected_eof (boundary, char const *);
static void unexpected_newline (boundary, char const *);

#line 1439 "src/scan-gram.c"
#line 128 "/Users/akim/src/gnu/bison/src/scan-gram.l"
 /* A C-like comment in directives/rules. */

 /* Characters and strings in directives/rules. */

 /* A identifier was just read in directives/rules.  Special state
    to capture the sequence 'identifier :'. */

 /* POSIX says that a tag must be both an id and a C union member, but
    historically almost any character is allowed in a tag.  We
    disallow NUL, as this simplifies our implementation.  We match
    angle brackets in nested pairs: several languages use them for
    generics/template types.  */

 /* Four types of user code:
    - prologue (code between '%{' '%}' in the first section, before %%);
    - actions, printers, union, etc, (between braced in the middle section);
    - epilogue (everything after the second %%).
    - predicate (code between '%?{' and '{' in middle section); */

 /* C and C++ comments in code. */

 /* Strings and characters in code. */

 /* Bracketed identifiers support. */

 /* UTF-8 Encoded Unicode Code Point, from Flex's documentation. */
/* Zero or more instances of backslash-newline.  Following GCC, allow
   white space between the backslash and the newline.  */
/* An equal sign, with optional leading whitespaces. This is used in some
   deprecated constructs. */
#line 1471 "src/scan-gram.c"

#define INITIAL 0
#define SC_YACC_COMMENT 1
#define SC_ESCAPED_CHARACTER 2
#define SC_ESCAPED_STRING 3
#define SC_ESCAPED_TSTRING 4
#define SC_AFTER_IDENTIFIER 5
#define SC_TAG 6
#define SC_PROLOGUE 7
#define SC_BRACED_CODE 8
#define SC_EPILOGUE 9
#define SC_PREDICATE 10
#define SC_COMMENT 11
#define SC_LINE_COMMENT 12
#define SC_STRING 13
#define SC_CHARACTER 14
#define SC_BRACKETED_ID 15
#define SC_RETURN_BRACKETED_ID 16

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
/* %if-c-only */
#include <unistd.h>
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* %if-c-only Reentrant structure and macros (non-C++). */
/* %if-reentrant */
/* %if-c-only */

static int yy_init_globals ( void );

/* %endif */
/* %if-reentrant */
/* %endif */
/* %endif End reentrant structures and macros. */

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* %if-bison-bridge */
/* %endif */

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

/* %not-for-header */
#ifndef YY_NO_UNPUT
    
    static void yyunput ( int c, char *buf_ptr  );
    
#endif
/* %ok-for-header */

/* %endif */

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
/* %if-c-only Standard (non-C++) definition */
/* %not-for-header */
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif
/* %ok-for-header */

/* %endif */
#endif

/* %if-c-only */

/* %endif */

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* %if-c-only Standard (non-C++) definition */
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
/* %% [5.0] fread()/read() definition of YY_INPUT goes here unless we're doing C++ \ */\
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\
/* %if-c++-only C++ definition \ */\
/* %endif */

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
/* %if-c-only */
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
/* %endif */
/* %if-c++-only */
/* %endif */
#endif

/* %if-tables-serialization structures and prototypes */
/* %not-for-header */
/* %ok-for-header */

/* %not-for-header */
/* %tables-yydmap generated elements */
/* %endif */
/* end tables serialization structures and prototypes */

/* %ok-for-header */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1
/* %if-c-only Standard (non-C++) definition */

extern int yylex (void);

#define YY_DECL int yylex (void)
/* %endif */
/* %if-c++-only C++ definition */
/* %endif */
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

/* %% [6.0] YY_RULE_SETUP definition goes here */
#define YY_RULE_SETUP \
	if ( yyleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(yytext[yyleng - 1] == '\n'); \
	YY_USER_ACTION

/* %not-for-header */
/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
/* %if-c-only */
			yyin = stdin;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! yyout )
/* %if-c-only */
			yyout = stdout;
/* %endif */
/* %if-c++-only */
/* %endif */

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
/* %% [7.0] user's declarations go here */
#line 175 "/Users/akim/src/gnu/bison/src/scan-gram.l"


  /* Nesting level.  Either for nested braces, or nested angle brackets
     (but not mixed).  */
  int nesting PACIFY_CC (= 0);

  /* Parent context state, when applicable.  */
  int context_state PACIFY_CC (= 0);

  /* Location of most recent identifier, when applicable.  */
  location id_loc PACIFY_CC (= empty_loc);

  /* Where containing code started, when applicable.  Its initial
     value is relevant only when yylex is invoked in the SC_EPILOGUE
     start condition.  */
  boundary code_start = scanner_cursor;

  /* Where containing comment or string or character literal started,
     when applicable.  */
  boundary token_start PACIFY_CC (= scanner_cursor);

  /* We cannot trust YY_USER_INIT, whose semantics changes over time
     (it moved in Flex 2.5.38).  */
  static bool first = true;
  if (first)
    {
      scanner_cursor = loc->start;
      first = false;
    }



  /*-----------------------.
  | Scanning white space.  |
  `-----------------------*/

#line 1807 "src/scan-gram.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
/* %% [8.0] yymore()-related code goes here */
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

/* %% [9.0] code to set up and find next match goes here */
		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 612 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			++yy_cp;
			}
		while ( yy_current_state != 611 );
		yy_cp = (yy_last_accepting_cpos);
		yy_current_state = (yy_last_accepting_state);

yy_find_action:
/* %% [10.0] code to find the action number goes here */
		yy_act = yy_accept[yy_current_state];

		YY_DO_BEFORE_ACTION;

/* %% [11.0] code for yylineno update goes here */

do_action:	/* This label is used only to access EOF actions. */

/* %% [12.0] debug code goes here */
		if ( yy_flex_debug )
			{
			if ( yy_act == 0 )
				fprintf( stderr, "--scanner backing up\n" );
			else if ( yy_act < 132 )
				fprintf( stderr, "--accepting rule at line %ld (\"%s\")\n",
				         (long)yy_rule_linenum[yy_act], yytext );
			else if ( yy_act == 132 )
				fprintf( stderr, "--accepting default rule (\"%s\")\n",
				         yytext );
			else if ( yy_act == 133 )
				fprintf( stderr, "--(end of buffer or a NUL)\n" );
			else
				fprintf( stderr, "--EOF (start condition %d)\n", YY_START );
			}

		switch ( yy_act )
	{ /* beginning of action switch */
/* %% [13.0] actions go here */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

/* Comments and white space.  */
case 1:
YY_RULE_SETUP
#line 214 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
     complain (loc, Wother, _("stray ',' treated as white space"));
  }
	YY_BREAK
case 2:
/* rule 2 can match eol */
#line 218 "/Users/akim/src/gnu/bison/src/scan-gram.l"
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 218 "/Users/akim/src/gnu/bison/src/scan-gram.l"
continue;
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 219 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    token_start = loc->start;
    context_state = YY_START;
    BEGIN SC_YACC_COMMENT;
  }
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 225 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    handle_syncline (yytext + sizeof "#line " - 1, *loc);
  }
	YY_BREAK

/*----------------------------.
  | Scanning Bison directives.  |
  `----------------------------*/
/* For directives that are also command line options, the regex must be
        "%..."
     after "[-_]"s are removed, and the directive must match the --long
     option name, with a single string argument.  Otherwise, add exceptions
     to ../build-aux/cross-options.pl.  */


case 6:
YY_RULE_SETUP
#line 243 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NONASSOC);
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 244 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (CODE);
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 245 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_FLAG ("parse.trace");
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 246 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DEFAULT_PREC);
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 247 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DEFINE);
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 248 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (HEADER); // Deprecated in 3.8.
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 249 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DESTRUCTOR);
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 250 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (DPREC);
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 251 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EMPTY);
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 252 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EXPECT);
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 253 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (EXPECT_RR);
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 254 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_FILE_PREFIX, uniqstr_new (yytext));
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 255 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (GLR_PARSER);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 256 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (HEADER);
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 257 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (INITIAL_ACTION);
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 258 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (LANGUAGE);
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 259 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_LEFT;
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 260 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (lex);
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 261 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_FLAG ("locations");
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 262 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (MERGE);
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 263 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NO_DEFAULT_PREC);
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 264 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NO_LINES);
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 265 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_NONASSOC;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 266 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NONDETERMINISTIC_PARSER);
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 267 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (NTERM);
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 268 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (OUTPUT);
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 269 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (both);
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 270 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_PERCENT_PARAM (parse);
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 271 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_PREC;
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 272 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (PRECEDENCE);
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 273 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (PRINTER);
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 274 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (REQUIRE);
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 275 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_RIGHT;
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 276 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (SKELETON);
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 277 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_START;
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 278 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (TOKEN);
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 279 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_TOKEN;
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 280 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (TOKEN_TABLE);
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 281 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_TYPE;
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 282 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_UNION;
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 283 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return BISON_DIRECTIVE (VERBOSE);
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 284 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PERCENT_YACC;
	YY_BREAK
/* Deprecated since Bison 2.3b (2008-05-27), but the warning is
     issued only since Bison 3.4. */
case 48:
YY_RULE_SETUP
#line 288 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_PURE_PARSER, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 3.0 (2013-07-25), but the warning is
     issued only since Bison 3.3. */
case 49:
YY_RULE_SETUP
#line 292 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_ERROR_VERBOSE, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 2.6 (2012-07-19), but the warning is
     issued only since Bison 3.3. */
case 50:
/* rule 50 can match eol */
YY_RULE_SETUP
#line 296 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_NAME_PREFIX, uniqstr_new (yytext));
	YY_BREAK
/* Deprecated since Bison 2.7.90, 2012. */
case 51:
YY_RULE_SETUP
#line 299 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%default-prec");
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 300 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_ERROR_VERBOSE, uniqstr_new (yytext));
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 301 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%expect-rr");
	YY_BREAK
case 54:
/* rule 54 can match eol */
YY_RULE_SETUP
#line 302 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (PERCENT_FILE_PREFIX, uniqstr_new (yytext));
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 303 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%output \"y.tab.c\"");
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 304 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%no-default-prec");
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 305 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%no-lines");
	YY_BREAK
case 58:
/* rule 58 can match eol */
YY_RULE_SETUP
#line 306 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%output");
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 307 "/Users/akim/src/gnu/bison/src/scan-gram.l"
DEPRECATED_DIRECTIVE ("%token-table");
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 309 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, _("invalid directive: %s"), quote (yytext));
    return GRAM_error;
  }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 314 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return COLON;
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 315 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return EQUAL;
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 316 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return PIPE;
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 317 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return SEMICOLON;
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 319 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    val->ID = uniqstr_new (yytext);
    id_loc = *loc;
    bracketed_id_str = NULL;
    BEGIN SC_AFTER_IDENTIFIER;
  }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 326 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (INT_LITERAL, scan_integer (yytext, 10, *loc));
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 327 "/Users/akim/src/gnu/bison/src/scan-gram.l"
RETURN_VALUE (INT_LITERAL, scan_integer (yytext, 16, *loc));
	YY_BREAK
/* Identifiers may not start with a digit.  Yet, don't silently
     accept "1FOO" as "1 FOO".  */
case 68:
YY_RULE_SETUP
#line 331 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, _("invalid identifier: %s"), quote (yytext));
    return GRAM_error;
  }
	YY_BREAK
/* Characters.  */
case 69:
YY_RULE_SETUP
#line 337 "/Users/akim/src/gnu/bison/src/scan-gram.l"
token_start = loc->start; BEGIN SC_ESCAPED_CHARACTER;
	YY_BREAK
/* Strings. */
case 70:
YY_RULE_SETUP
#line 340 "/Users/akim/src/gnu/bison/src/scan-gram.l"
token_start = loc->start; STRING_1GROW ('"'); BEGIN SC_ESCAPED_STRING;
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 341 "/Users/akim/src/gnu/bison/src/scan-gram.l"
token_start = loc->start; STRING_1GROW ('"'); BEGIN SC_ESCAPED_TSTRING;
	YY_BREAK
/* Prologue. */
case 72:
YY_RULE_SETUP
#line 344 "/Users/akim/src/gnu/bison/src/scan-gram.l"
code_start = loc->start; BEGIN SC_PROLOGUE;
	YY_BREAK
/* Code in between braces.  */
case 73:
YY_RULE_SETUP
#line 347 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    nesting = 0;
    code_start = loc->start;
    BEGIN SC_BRACED_CODE;
  }
	YY_BREAK
/* Semantic predicate. */
case 74:
/* rule 74 can match eol */
YY_RULE_SETUP
#line 355 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    nesting = 0;
    code_start = loc->start;
    BEGIN SC_PREDICATE;
  }
	YY_BREAK
/* A type. */
case 75:
YY_RULE_SETUP
#line 362 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return TAG_ANY;
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 363 "/Users/akim/src/gnu/bison/src/scan-gram.l"
return TAG_NONE;
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 364 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    nesting = 0;
    token_start = loc->start;
    BEGIN SC_TAG;
  }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 370 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    static int percent_percent_count;
    if (++percent_percent_count == 2)
      BEGIN SC_EPILOGUE;
    return PERCENT_PERCENT;
  }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 377 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    bracketed_id_str = NULL;
    bracketed_id_start = loc->start;
    bracketed_id_context_state = YY_START;
    BEGIN SC_BRACKETED_ID;
  }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 384 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, "%s: %s",
              ngettext ("invalid character", "invalid characters", yyleng),
              quote_mem (yytext, yyleng));
    return GRAM_error;
  }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 391 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    loc->start = loc->end = scanner_cursor;
    yyterminate ();
  }
	YY_BREAK

/*--------------------------------------------------------------.
  | Supporting \0 complexifies our implementation for no expected |
  | added value.                                                  |
  `--------------------------------------------------------------*/


case 81:
YY_RULE_SETUP
#line 405 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, _("invalid null character"));
    STRING_FINISH ();
    STRING_FREE ();
    return GRAM_error;
  }
	YY_BREAK

/*-----------------------------------------------------------------.
  | Scanning after an identifier, checking whether a colon is next.  |
  `-----------------------------------------------------------------*/


case 82:
YY_RULE_SETUP
#line 420 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    if (bracketed_id_str)
      {
        ROLLBACK_CURRENT_TOKEN;
        BEGIN SC_RETURN_BRACKETED_ID;
        *loc = id_loc;
        return ID;
      }
    else
      {
        bracketed_id_start = loc->start;
        bracketed_id_context_state = YY_START;
        BEGIN SC_BRACKETED_ID;
      }
  }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 435 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID_COLON;
  }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 441 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID;
  }
	YY_BREAK
case YY_STATE_EOF(SC_AFTER_IDENTIFIER):
#line 447 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN (bracketed_id_str ? SC_RETURN_BRACKETED_ID : INITIAL);
    *loc = id_loc;
    return ID;
  }
	YY_BREAK

/*--------------------------------.
  | Scanning bracketed identifiers. |
  `--------------------------------*/


case 85:
YY_RULE_SETUP
#line 460 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    if (bracketed_id_str)
      {
        complain (loc, complaint,
                  _("unexpected identifier in bracketed name: %s"),
                  quote (yytext));
        return GRAM_error;
      }
    else
      {
        bracketed_id_str = uniqstr_new (yytext);
        bracketed_id_loc = *loc;
      }
  }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 474 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN bracketed_id_context_state;
    if (bracketed_id_str)
      {
        if (INITIAL == bracketed_id_context_state)
          {
            val->BRACKETED_ID = bracketed_id_str;
            bracketed_id_str = 0;
            *loc = bracketed_id_loc;
            return BRACKETED_ID;
          }
      }
    else
      {
        complain (loc, complaint, _("an identifier expected"));
        return GRAM_error;
      }
  }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 493 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    complain (loc, complaint, "%s: %s",
              ngettext ("invalid character in bracketed name",
                        "invalid characters in bracketed name", yyleng),
              quote_mem (yytext, yyleng));
    return GRAM_error;
  }
	YY_BREAK
case YY_STATE_EOF(SC_BRACKETED_ID):
#line 501 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    BEGIN bracketed_id_context_state;
    unexpected_eof (bracketed_id_start, "]");
  }
	YY_BREAK



case 88:
YY_RULE_SETUP
#line 509 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    ROLLBACK_CURRENT_TOKEN;
    val->BRACKETED_ID = bracketed_id_str;
    bracketed_id_str = 0;
    *loc = bracketed_id_loc;
    BEGIN INITIAL;
    return BRACKETED_ID;
  }
	YY_BREAK

/*---------------------------------------------------------------.
  | Scanning a Yacc comment.  The initial '/ *' is already eaten.  |
  `---------------------------------------------------------------*/


case 89:
YY_RULE_SETUP
#line 526 "/Users/akim/src/gnu/bison/src/scan-gram.l"
BEGIN context_state;
	YY_BREAK
case 90:
/* rule 90 can match eol */
YY_RULE_SETUP
#line 527 "/Users/akim/src/gnu/bison/src/scan-gram.l"
continue;
	YY_BREAK
case YY_STATE_EOF(SC_YACC_COMMENT):
#line 528 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "*/"); BEGIN context_state;
	YY_BREAK

/*------------------------------------------------------------.
  | Scanning a C comment.  The initial '/ *' is already eaten.  |
  `------------------------------------------------------------*/


case 91:
/* rule 91 can match eol */
YY_RULE_SETUP
#line 538 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); BEGIN context_state;
	YY_BREAK
case YY_STATE_EOF(SC_COMMENT):
#line 539 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "*/"); BEGIN context_state;
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning a line comment.  The initial '//' is already eaten.  |
  `--------------------------------------------------------------*/


case 92:
/* rule 92 can match eol */
YY_RULE_SETUP
#line 549 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); BEGIN context_state;
	YY_BREAK
case 93:
/* rule 93 can match eol */
YY_RULE_SETUP
#line 550 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK
case YY_STATE_EOF(SC_LINE_COMMENT):
#line 551 "/Users/akim/src/gnu/bison/src/scan-gram.l"
BEGIN context_state;
	YY_BREAK

/*------------------------------------------------.
  | Scanning a Bison string, including its escapes. |
  | The initial quote is already eaten.             |
  `------------------------------------------------*/


case 94:
YY_RULE_SETUP
#line 562 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_1GROW ('"');
    STRING_FINISH ();
    BEGIN INITIAL;
    loc->start = token_start;
    complain (loc, Wyacc,
              _("POSIX Yacc does not support string literals"));
    RETURN_VALUE (STRING, last_string);
  }
	YY_BREAK
case YY_STATE_EOF(SC_ESCAPED_STRING):
#line 571 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "\"");
	YY_BREAK
case 95:
/* rule 95 can match eol */
YY_RULE_SETUP
#line 572 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "\"");
	YY_BREAK



case 96:
YY_RULE_SETUP
#line 577 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_1GROW ('"');
    STRING_FINISH ();
    BEGIN INITIAL;
    loc->start = token_start;
    complain (loc, Wyacc,
              _("POSIX Yacc does not support string literals"));
    RETURN_VALUE (TSTRING, last_string);
  }
	YY_BREAK
case YY_STATE_EOF(SC_ESCAPED_TSTRING):
#line 586 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "\")");
	YY_BREAK
case 97:
/* rule 97 can match eol */
YY_RULE_SETUP
#line 587 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "\")");
	YY_BREAK

/*----------------------------------------------------------.
  | Scanning a Bison character literal, decoding its escapes. |
  | The initial quote is already eaten.                       |
  `----------------------------------------------------------*/


case 98:
YY_RULE_SETUP
#line 599 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH ();
    BEGIN INITIAL;
    loc->start = token_start;

    if (last_string[0] == '\0')
      {
        complain (loc, complaint, _("empty character literal"));
        STRING_FREE ();
        return GRAM_error;
      }
    else if (last_string[1] != '\0')
      {
        complain (loc, complaint, _("extra characters in character literal"));
        STRING_FREE ();
        return GRAM_error;
      }
    else
      {
        val->CHAR_LITERAL = last_string[0];
        STRING_FREE ();
        return CHAR_LITERAL;
      }
  }
	YY_BREAK
case 99:
/* rule 99 can match eol */
YY_RULE_SETUP
#line 623 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "'");
	YY_BREAK
case YY_STATE_EOF(SC_ESCAPED_CHARACTER):
#line 624 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "'");
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning a tag.  The initial angle bracket is already eaten.  |
  `--------------------------------------------------------------*/


case 100:
YY_RULE_SETUP
#line 635 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH ();
        loc->start = token_start;
        val->TAG = uniqstr_new (last_string);
        STRING_FREE ();
        BEGIN INITIAL;
        return TAG;
      }
    STRING_GROW ();
  }
	YY_BREAK
case 101:
/* rule 101 can match eol */
YY_RULE_SETUP
#line 649 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 650 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); nesting += yyleng;
	YY_BREAK
case YY_STATE_EOF(SC_TAG):
#line 652 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, ">");
	YY_BREAK

/*----------------------------.
  | Decode escaped characters.  |
  `----------------------------*/


case 103:
YY_RULE_SETUP
#line 661 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW_ESCAPE (strtol (yytext + 1, NULL, 8));
  }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 665 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW_ESCAPE (strtol (yytext + 2, NULL, 16));
  }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 669 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\a');
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 670 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\b');
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 671 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\f');
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 672 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\n');
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 673 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\r');
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 674 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\t');
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 675 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE ('\v');
	YY_BREAK
/* \\[\"\'?\\] would be shorter, but it confuses xgettext.  */
case 112:
YY_RULE_SETUP
#line 678 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW_ESCAPE (yytext[1]);
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 680 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW_ESCAPE (convert_ucn_to_byte (yytext));
  }
	YY_BREAK
case 114:
/* rule 114 can match eol */
YY_RULE_SETUP
#line 684 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    char const *p = yytext + 1;
    /* Quote only if escaping won't make the character visible.  */
    if (c_isspace ((unsigned char) *p) && c_isprint ((unsigned char) *p))
      p = quote (p);
    else
      p = quotearg_style_mem (escape_quoting_style, p, 1);
    complain (loc, complaint, _("invalid character after \\-escape: %s"),
              p);
    STRING_1GROW ('?');
  }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 696 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    // None of the other rules matched: the last character of this
    // file is "\".  But Flex does not support "\\<<EOF>>".
    unexpected_eof (token_start,
                    YY_START == SC_ESCAPED_CHARACTER ? "?'"
                    : YY_START == SC_ESCAPED_STRING ? "?\""
                    : "?\")");
  }
	YY_BREAK

/*--------------------------------------------.
  | Scanning user-code characters and strings.  |
  `--------------------------------------------*/


case 116:
/* rule 116 can match eol */
YY_RULE_SETUP
#line 712 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK



case 117:
YY_RULE_SETUP
#line 717 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); BEGIN context_state;
	YY_BREAK
case 118:
/* rule 118 can match eol */
YY_RULE_SETUP
#line 718 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "'");
	YY_BREAK
case YY_STATE_EOF(SC_CHARACTER):
#line 719 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "'");
	YY_BREAK



case 119:
YY_RULE_SETUP
#line 724 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); BEGIN context_state;
	YY_BREAK
case 120:
/* rule 120 can match eol */
YY_RULE_SETUP
#line 725 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_newline (token_start, "\"");
	YY_BREAK
case YY_STATE_EOF(SC_STRING):
#line 726 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (token_start, "\"");
	YY_BREAK

/*---------------------------------------------------.
  | Strings, comments etc. can be found in user code.  |
  `---------------------------------------------------*/


case 121:
YY_RULE_SETUP
#line 736 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_CHARACTER;
  }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 742 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_STRING;
  }
	YY_BREAK
case 123:
/* rule 123 can match eol */
YY_RULE_SETUP
#line 748 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    context_state = YY_START;
    token_start = loc->start;
    BEGIN SC_COMMENT;
  }
	YY_BREAK
case 124:
/* rule 124 can match eol */
YY_RULE_SETUP
#line 754 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_GROW ();
    context_state = YY_START;
    BEGIN SC_LINE_COMMENT;
  }
	YY_BREAK

/*-----------------------------------------------------------.
  | Scanning some code in braces (actions, predicates). The    |
  | initial "{" is already eaten.                              |
  `-----------------------------------------------------------*/


case 125:
/* rule 125 can match eol */
YY_RULE_SETUP
#line 770 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); nesting++;
	YY_BREAK
case 126:
/* rule 126 can match eol */
YY_RULE_SETUP
#line 771 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW (); nesting--;
	YY_BREAK
/* Tokenize '<<%' correctly (as '<<' '%') rather than incorrectly
     (as '<' '<%').  */
case 127:
/* rule 127 can match eol */
YY_RULE_SETUP
#line 775 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK
case YY_STATE_EOF(SC_BRACED_CODE):
case YY_STATE_EOF(SC_PREDICATE):
#line 777 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (code_start, "}");
	YY_BREAK



case 128:
YY_RULE_SETUP
#line 782 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_1GROW ('}');

    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH ();
        loc->start = code_start;
        BEGIN INITIAL;
        RETURN_VALUE (BRACED_CODE, last_string);
      }
  }
	YY_BREAK



case 129:
YY_RULE_SETUP
#line 798 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    --nesting;
    if (nesting < 0)
      {
        STRING_FINISH ();
        loc->start = code_start;
        BEGIN INITIAL;
        RETURN_VALUE (BRACED_PREDICATE, last_string);
      }
    else
      STRING_1GROW ('}');
  }
	YY_BREAK

/*--------------------------------------------------------------.
  | Scanning some prologue: from "%{" (already scanned) to "%}".  |
  `--------------------------------------------------------------*/


case 130:
YY_RULE_SETUP
#line 818 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH ();
    loc->start = code_start;
    BEGIN INITIAL;
    RETURN_VALUE (PROLOGUE, last_string);
  }
	YY_BREAK
case YY_STATE_EOF(SC_PROLOGUE):
#line 825 "/Users/akim/src/gnu/bison/src/scan-gram.l"
unexpected_eof (code_start, "%}");
	YY_BREAK

/*---------------------------------------------------------------.
  | Scanning the epilogue (everything after the second "%%", which |
  | has already been eaten).                                       |
  `---------------------------------------------------------------*/


case YY_STATE_EOF(SC_EPILOGUE):
#line 836 "/Users/akim/src/gnu/bison/src/scan-gram.l"
{
    STRING_FINISH ();
    loc->start = code_start;
    BEGIN INITIAL;
    RETURN_VALUE (EPILOGUE, last_string);
  }
	YY_BREAK

/*-----------------------------------------------------.
  | By default, grow the string obstack with the input.  |
  `-----------------------------------------------------*/


/* Accept multibyte characters in one block instead of byte after
     byte, so that add_column_width and mbsnwidth can compute correct
     screen width.

     Add a fallthrough "|." so that non UTF-8 input is still accepted
     and does not jam the scanner.  */
case 131:
/* rule 131 can match eol */
YY_RULE_SETUP
#line 857 "/Users/akim/src/gnu/bison/src/scan-gram.l"
STRING_GROW ();
	YY_BREAK

case 132:
YY_RULE_SETUP
#line 860 "/Users/akim/src/gnu/bison/src/scan-gram.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 3037 "src/scan-gram.c"
case YY_STATE_EOF(SC_RETURN_BRACKETED_ID):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
/* %if-c-only */
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
/* %endif */
/* %if-c++-only */
/* %endif */
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
/* %% [14.0] code to do back-up for compressed tables and set up yy_cp goes here */
				yy_cp = (yy_last_accepting_cpos);
				yy_current_state = (yy_last_accepting_state);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */
/* %ok-for-header */

/* %if-c++-only */
/* %not-for-header */
/* %ok-for-header */

/* %endif */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
/* %if-c-only */
static int yy_get_next_buffer (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					yyrealloc( (void *) b->yy_ch_buf,
							 (yy_size_t) (b->yy_buf_size + 2)  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

/* %if-c-only */
/* %not-for-header */
    static yy_state_type yy_get_previous_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
/* %% [15.0] code to get the start state into yy_current_state goes here */
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
/* %% [16.0] code to find the next state goes here */
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 72);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 612 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
/* %if-c-only */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	int yy_is_jam;
    /* %% [17.0] code to find the next state, and perhaps do backing up, goes here */
	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 72;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 612 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 611);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT
/* %if-c-only */

    static void yyunput (int c, char * yy_bp )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	char *yy_cp;
    
    yy_cp = (yy_c_buf_p);

	/* undo effects of setting up yytext */
	*yy_cp = (yy_hold_char);

	if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
		{ /* need to shift things up to make room */
		/* +2 for EOB chars. */
		int number_to_move = (yy_n_chars) + 2;
		char *dest = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[
					YY_CURRENT_BUFFER_LVALUE->yy_buf_size + 2];
		char *source =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move];

		while ( source > YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			*--dest = *--source;

		yy_cp += (int) (dest - source);
		yy_bp += (int) (dest - source);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars =
			(yy_n_chars) = (int) YY_CURRENT_BUFFER_LVALUE->yy_buf_size;

		if ( yy_cp < YY_CURRENT_BUFFER_LVALUE->yy_ch_buf + 2 )
			YY_FATAL_ERROR( "flex scanner push-back overflow" );
		}

	*--yy_cp = (char) c;

/* %% [18.0] update yylineno here */

	(yytext_ptr) = yy_bp;
	(yy_hold_char) = *yy_cp;
	(yy_c_buf_p) = yy_cp;
}
/* %if-c-only */

/* %endif */
#endif

/* %if-c-only */
#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

/* %endif */
/* %if-c++-only */
/* %endif */
{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

/* %% [19.0] update BOL and yylineno */
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
/* %if-c-only */
#endif	/* ifndef YY_NO_INPUT */
/* %endif */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
/* %if-c-only */
    void yyrestart  (FILE * input_file )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/* %if-c++-only */
/* %endif */

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
/* %if-c-only */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

/* %if-c-only */
static void yy_load_buffer_state  (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
/* %if-c-only */
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
/* %endif */
/* %if-c++-only */
/* %endif */
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
/* %if-c-only */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
/* %endif */
/* %if-c++-only */
/* %endif */
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/* %if-c++-only */
/* %endif */

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
/* %if-c-only */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
/* %if-c-only */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )
/* %endif */
/* %if-c++-only */
/* %endif */

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

/* %if-c-only */
	b->yy_input_file = file;
/* %endif */
/* %if-c++-only */
/* %endif */
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

/* %if-c-only */

        b->yy_is_interactive = 0;
    
/* %endif */
/* %if-c++-only */
/* %endif */
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
/* %if-c-only */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/* %if-c-or-c++ */
/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
/* %if-c-only */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}
/* %endif */

/* %if-c-or-c++ */
/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
/* %if-c-only */
void yypop_buffer_state (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}
/* %endif */

/* %if-c-or-c++ */
/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
/* %if-c-only */
static void yyensure_buffer_stack (void)
/* %endif */
/* %if-c++-only */
/* %endif */
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}
/* %endif */

/* %if-c-only */
/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}
/* %endif */

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

/* %if-c-only */
static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}
/* %endif */
/* %if-c++-only */
/* %endif */

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/* %if-c-only */
/* %if-reentrant */
/* %endif */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/* %if-reentrant */
/* %endif */

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

/* %endif */

/* %if-reentrant */
/* %if-bison-bridge */
/* %endif */
/* %endif if-c-only */

/* %if-c-only */
static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}
/* %endif */

/* %if-c-only SNIP! this currently causes conflicts with the c++ scanner */
/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

/* %if-reentrant */
/* %endif */
    return 0;
}
/* %endif */

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

/* %if-tables-serialization definitions */
/* %define-yytables   The name for this specific scanner's tables. */
#define YYTABLES_NAME "yytables"
/* %endif */

/* %ok-for-header */

#line 860 "/Users/akim/src/gnu/bison/src/scan-gram.l"



/*------------------------------------------------------.
| Scan NUMBER for a base-BASE integer at location LOC.  |
`------------------------------------------------------*/

static int
scan_integer (char const *number, int base, location loc)
{
  verify (INT_MAX < ULONG_MAX);
  if (base == 16)
    complain (&loc, Wyacc,
              _("POSIX Yacc does not support hexadecimal literals"));

  errno = 0;
  long num = strtol (number, NULL, base);

  if (! (0 <= num && num <= INT_MAX && errno == 0))
    {
      complain (&loc, complaint, _("integer out of range: %s"),
                quote (number));
      num = INT_MAX;
    }

  return num;
}


/*------------------------------------------------------------------.
| Convert universal character name UCN to a single-byte character,  |
| and return that character.  Return -1 if UCN does not correspond  |
| to a single-byte character.                                       |
`------------------------------------------------------------------*/

static int
convert_ucn_to_byte (char const *ucn)
{
  verify (UCHAR_MAX <= INT_MAX);
  long code = strtol (ucn + 2, NULL, 16);

  /* FIXME: Currently we assume Unicode-compatible unibyte characters
     on ASCII hosts (i.e., Latin-1 on hosts with 8-bit bytes).  On
     non-ASCII hosts we support only the portable C character set.
     These limitations should be removed once we add support for
     multibyte characters.  */

  if (! (0 <= code && code <= UCHAR_MAX))
    return -1;

#if ! ('$' == 0x24 && '@' == 0x40 && '`' == 0x60 && '~' == 0x7e)
  {
    /* A non-ASCII host.  Use CODE to index into a table of the C
       basic execution character set, which is guaranteed to exist on
       all Standard C platforms.  This table also includes '$', '@',
       and '`', which are not in the basic execution character set but
       which are unibyte characters on all the platforms that we know
       about.  */
    static signed char const table[] =
      {
        '\0',   -1,   -1,   -1,   -1,   -1,   -1, '\a',
        '\b', '\t', '\n', '\v', '\f', '\r',   -1,   -1,
          -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
          -1,   -1,   -1,   -1,   -1,   -1,   -1,   -1,
         ' ',  '!',  '"',  '#',  '$',  '%',  '&', '\'',
         '(',  ')',  '*',  '+',  ',',  '-',  '.',  '/',
         '0',  '1',  '2',  '3',  '4',  '5',  '6',  '7',
         '8',  '9',  ':',  ';',  '<',  '=',  '>',  '?',
         '@',  'A',  'B',  'C',  'D',  'E',  'F',  'G',
         'H',  'I',  'J',  'K',  'L',  'M',  'N',  'O',
         'P',  'Q',  'R',  'S',  'T',  'U',  'V',  'W',
         'X',  'Y',  'Z',  '[', '\\',  ']',  '^',  '_',
         '`',  'a',  'b',  'c',  'd',  'e',  'f',  'g',
         'h',  'i',  'j',  'k',  'l',  'm',  'n',  'o',
         'p',  'q',  'r',  's',  't',  'u',  'v',  'w',
         'x',  'y',  'z',  '{',  '|',  '}',  '~'
      };

    code = code < sizeof table ? table[code] : -1;
  }
#endif

  return code;
}


/*----------------------------------------------------------------------------.
| Handle '#line INT_LITERAL( "FILE")?\n'.  ARGS has already skipped '#line '. |
`----------------------------------------------------------------------------*/

static void
handle_syncline (char *args, location loc)
{
  char *file;
  errno = 0;
  long lineno = strtol (args, &file, 10);
  if (! (0 <= lineno && lineno <= INT_MAX && errno == 0))
    {
      complain (&loc, Wother, _("line number overflow"));
      lineno = INT_MAX;
    }

  file = strchr (file, '"');
  if (file)
    {
      *strchr (file + 1, '"') = '\0';
      current_file = uniqstr_new (file + 1);
    }
  boundary_set (&scanner_cursor, current_file, lineno, 1, 1);
}


/*----------------------------------------------------------------.
| For a token or comment starting at START, report message MSGID, |
| which should say that an end marker was found before the        |
| expected TOKEN_END. Then, pretend that TOKEN_END was found.     |
`----------------------------------------------------------------*/

static void
unexpected_end (boundary start, char const *msgid, char const *token_end)
{
  location loc;
  loc.start = start;
  loc.end = scanner_cursor;
  size_t i = strlen (token_end);

  /* Adjust scanner cursor so that any later message does not count
     the characters about to be inserted.  */
  scanner_cursor.column -= i;
  scanner_cursor.byte -= i;

  while (i != 0)
    unput (token_end[--i]);

  token_end = quote (token_end);
  /* Instead of '\'', display "'".  */
  if (STREQ (token_end, "'\\''"))
    token_end = "\"'\"";
  complain (&loc, complaint, msgid, token_end);
}


/*------------------------------------------------------------------------.
| Report an unexpected EOF in a token or comment starting at START.       |
| An end of file was encountered and the expected TOKEN_END was missing.  |
| After reporting the problem, pretend that TOKEN_END was found.          |
`------------------------------------------------------------------------*/

static void
unexpected_eof (boundary start, char const *token_end)
{
  unexpected_end (start, _("missing %s at end of file"), token_end);
}


/*----------------------------------------.
| Likewise, but for unexpected newlines.  |
`----------------------------------------*/

static void
unexpected_newline (boundary start, char const *token_end)
{
  unexpected_end (start, _("missing %s at end of line"), token_end);
}


void
gram_scanner_open (const char *gram)
{
  gram__flex_debug = trace_flag & trace_scan;
  gram_debug = trace_flag & trace_parse;
  obstack_init (&obstack_for_string);
  current_file = gram;
  gram_in = xfopen (gram, "r");
}


void
gram_scanner_close (void)
{
  xfclose (gram_in);
  /* Reclaim Flex's buffers.  */
  yylex_destroy ();
}


void
gram_scanner_free (void)
{
  obstack_free (&obstack_for_string, 0);
}

